@@ -9,7 +9,7 @@ Data Ingestion into the Switch Automation
 
 Complete package for ingestion data into the Switch Automation Platform.
 """
-__all__ = ['dataset', 'analytics', 'pipeline', 'error_handlers', 'platform_insights', 'integration', 'initialize']
+__all__ = ['dataset', 'analytics', 'pipeline', 'error_handlers', 'integration', 'initialize', 'cache']
 
 from .initialize import initialize
 from . import dataset
@@ -18,6 +18,7 @@ from . import pipeline
 from . import error_handlers
 # from . import platform_insights
 from . import integration
+from . import cache
 
 
 # import logging
@@ -32,4 +33,4 @@ from . import integration
 # log.addHandler(_ch)
 # https://dev.to/joaomcteixeira/setting-up-python-logging-for-a-library-app-6ml
 
-__version__ = "0.2.10"
+__version__ = "0.2.11"
