@@ -11,7 +11,7 @@ from typing import Literal
 __all__ = ['api_prefix', 'argus_prefix', 'DATETIME_COL_FMT', 'DEPLOY_TYPE', 'EXPECTED_DELIVERY', 'WORK_ORDER_PRIORITY',
            'WORK_ORDER_STATUS', 'WORK_ORDER_CATEGORY', 'ERROR_TYPE', 'MAPPING_ENTITIES', 'QUEUE_NAME', 'QUERY_LANGUAGE',
            'ACCOUNT', 'PROCESS_STATUS', 'AUTH_ENDPOINT_DEV', 'AUTH_ENDPOINT_PROD', 'SCHEDULE_TIMEZONE',
-           'SWITCH_ENVIRONMENT', 'INTEGRATION_SETTINGS_EDITORS', 'DATA_INGESTION_CONTAINER']
+           'SWITCH_ENVIRONMENT', 'INTEGRATION_SETTINGS_EDITORS', 'DATA_INGESTION_CONTAINER', 'CACHE_SCOPE']
 
 # @deprecated suggestion: Up for deprecation as this is not used anymore in the API
 # api_prefix = "http://localhost:7071/api/SwitchApi/"
@@ -66,3 +66,5 @@ SUPPORT_PAYLOAD_TYPE = Literal['Sites', 'Sensors', 'Portfolio']
 
 INTEGRATION_SETTINGS_EDITORS = Literal['text_box', 'numeric_stepper', 'custom_combo', 'tag_groups_combo',
                                        'equipment_combo']
+
+CACHE_SCOPE = Literal['Portfolio', 'Task', 'DataFeed']
\ No newline at end of file
