@@ -9,10 +9,11 @@ A module for .....
 from azure.storage.blob import ContainerClient
 import uuid
 import pandas
+import time
 import requests
 import logging
 import sys
-from .._utils._constants import ACCOUNT
+from .._utils._constants import ACCOUNT, DATA_INGESTION_CONTAINER
 from .._utils._utils import ApiInputs
 
 logger = logging.getLogger(__name__)
@@ -144,8 +145,8 @@ class Blob:
         return blob_client.download_blob().readall()
 
     @staticmethod
-    def upload(api_inputs: ApiInputs, data_frame: pandas.DataFrame, name: str, api_project_id, is_timeseries: bool,
-               account: ACCOUNT = 'DataIngestion', batch_id: uuid.UUID = ''):
+    def upload(api_inputs: ApiInputs, data_frame: pandas.DataFrame, name: str, batch_id: uuid.UUID = None, account: ACCOUNT = 'DataIngestion',
+               container: DATA_INGESTION_CONTAINER = 'data-ingestion-adx', folder: str = 'to-ingest', include_header: bool = False):
         """Upload data to blob.
 
         Parameters
@@ -153,18 +154,20 @@ class Blob:
         api_inputs : ApiInputs
             Object returned by initialize() function.
         account: ACCOUNT, optional
-            Blob account data will be uploaded to (Default value = 'SwitchStorage').
+            Blob account data will be uploaded to (Default value = 'DataIngestion').
         data_frame : pandas.DataFrame
             Dataframe containing the data to be uploaded to blob.
         name : str
             Name.
-        api_project_id : uuid.UUID
-            ApiProjectID of the portfolio data is being uploaded for.
-        is_timeseries : bool
-            Define whether the data being uploaded is timeseries data or not.
-        batch_id : str, default = ''
-            Batch ID (Default value = '').
-
+        batch_id : str
+            Data feed file status id.
+        folder: str
+            Top folder inside the container assigned to the uploaded blob. (Default value = 'to-ingest')
+        container: DATA_INGESTION_CONTAINER
+            Container name (Literal) to where the blob goes into. (Default value = 'data-ingestion-adx')
+        include_header: bool
+            Boolean if include data frame's headers in the output file.
+            Default to False
         Returns
         -------
 
@@ -176,13 +179,25 @@ class Blob:
                          'ACCOUNT literal: %s', ACCOUNT.__args__)
             return False
 
-        container = "data-ingestion-adx"
+        if not set([container]).issubset(set(DATA_INGESTION_CONTAINER.__args__)):
+            logger.error('container parameter must be set to one of the allowed values defined by the '
+                         'DATA_INGESTION_CONTAINER literal: %s', DATA_INGESTION_CONTAINER.__args__)
+            return False
+
+        if batch_id is None or batch_id == '00000000-0000-0000-0000-000000000000' or batch_id == '':
+            if api_inputs.data_feed_file_status_id is None \
+                    or api_inputs.data_feed_file_status_id == '00000000-0000-0000-0000-000000000000':
+                batch_id = uuid.uuid4()
+            else:
+                batch_id = api_inputs.data_feed_file_status_id
+
         container_con_string = _get_container_sas_uri(api_inputs, container, account, True)
         container_client = ContainerClient.from_container_url(container_con_string)
 
         list_chunked_df = [data_frame[count:count + chunk_size] for count in
                            range(0, data_frame.shape[0], chunk_size)]
-        upload_path = "to-ingest/" + str(uuid.uuid1()) + "/" + name + "/"
+
+        upload_path = f"{folder}/{api_inputs.api_project_id}/{name}/{batch_id}/{time.time_ns()}_"
 
         item_counter = 0
         for current_data_frame in list_chunked_df:
@@ -190,7 +205,7 @@ class Blob:
             blob_name = upload_path + str(item_counter) + ".csv"
             logger.info("Uploading ... %s", blob_name)
             blob_client = container_client.get_blob_client(blob_name)
-            data_csv = bytes(current_data_frame.to_csv(line_terminator='\r\n', index=False, header=False),
+            data_csv = bytes(current_data_frame.to_csv(line_terminator='\r\n', index=False, header=include_header),
                              encoding='utf-8')
             blob_client.upload_blob(data_csv, blob_type="BlockBlob", overwrite=True)
 
