@@ -9,7 +9,7 @@ A module for integrating asset creation, asset updates, data ingestion, etc into
 
 from .integration import (upsert_data, upsert_sites, upsert_workorders, upsert_device_sensors,
                           upsert_timeseries_ds, replace_data, append_data, upsert_file_row_count,
-                          upsert_discovered_records)
+                          upsert_discovered_records, upsert_timeseries)
 
 from .helpers import (get_sites, get_tag_groups, get_metadata_keys, get_data, get_device_sensors, get_templates,
                       get_units_of_measure, get_states_by_country, get_operation_state, get_equipment_classes,
@@ -19,4 +19,4 @@ __all__ = ['upsert_data', 'upsert_sites', 'upsert_workorders', 'upsert_device_se
            'replace_data', 'append_data', 'get_sites', 'get_tag_groups', 'get_metadata_keys', 'get_data',
            'get_device_sensors', 'get_templates', 'get_units_of_measure', 'get_states_by_country',
            'get_operation_state', 'get_equipment_classes', 'load_data', 'upsert_file_row_count',
-           'upsert_discovered_records']
+           'upsert_discovered_records', 'upsert_timeseries']
