@@ -6,7 +6,6 @@
 """
 A module for integrating asset creation, asset updates, data ingestion, etc into the Switch Automation Platform.
 """
-import json
 import re
 import sys
 import pandas
@@ -14,7 +13,6 @@ import pandas as pd
 import pandera
 import requests
 import datetime
-import pytz
 import logging
 import uuid
 from .._utils._platform import _get_structure, Blob
